polyfemos.back.station — polyfemos 0.3.29 documentation

# polyfemos.back.station

Contains classes for handling station information

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.back.station.` `get_id`(network_code, station_code)
  Parameters

    - network_code (str) –

    - station_code (str) –

  Return type

    str

  Returns

    `network_code + "." + station_code`, e.g. “FN.MSF”

Classes

`Station`([network_code, station_code, …]) | Class for handling information of one station
`Stations`() | Class for containing and handling multiple `Station` instances